Module parser

Module parser 

Structs

ActiveIngredient
Active ingredient composition for a prescription
ActiveIngridientRecord
AdminRoute
Administration route for a prescription
AdministrationRouteRecord
AtcDuplicate
ATC duplicate information
AtcRecord
ContainerRecord
ContainerUnitRecord
DcpRecord
DcpfRecord
DcsaRecord
ExcipientRecord
Header
LaboratoryRecord
PharmaceuticalFormRecord
PrescriptionAtc
ATC code for a prescription
PrescriptionForm
Pharmaceutical form for a prescription
PrescriptionList
PrescriptionRecord
RegistrationStatusRecord
SimplifiedPharmaceuticalFormRecord
SupplyProblem
Supply problem for a prescription

Functions

parse_atc_xml_to_csv
Parses the ATC XML file and writes its content to a CSV file.
parse_dcp_xml_to_csv
Parses the DCP XML file and writes its content to a CSV file.
parse_dcpf_xml_to_csv
Parses the DCPF XML file and writes its content to a CSV file.
parse_dcsa_xml_to_csv
Parses the DCSA XML file and writes its content to a CSV file.
parse_envases_xml_to_csv
Parses the Envases XML file and writes its content to a CSV file.
parse_excipientes_xml_to_csv
Parses the Excipientes XML file and writes its content to a CSV file.
parse_forma_farmaceutica_simplificada_xml_to_csv
Parses the Forma Farmaceutica Simplificada XML file and writes its content to a CSV file.
parse_forma_farmaceutica_xml_to_csv
Parses the Forma Farmaceutica XML file and writes its content to a CSV file.
parse_laboratorio_xml_to_csv
Parses the Laboratorio XML file and writes its content to a CSV file.
parse_prescription_xml_to_csv
Parses the Prescription XML file and writes its content to a CSV file.
parse_prescription_xml_to_csvs
Parses the Prescription XML file and writes content to multiple CSV files for normalized data.
parse_principio_activo_xml_to_csv
Parses the Principio Activo XML file and writes its content to a CSV file.
parse_situacion_registro_xml_to_csv
Parses the Situacion Registro XML file and writes its content to a CSV file.
parse_unidad_contenido_xml_to_csv
Parses the Unidad Contenido XML file and writes its content to a CSV file.
parse_via_administracion_xml_to_csv
Parses the Via Administracion XML file and writes its content to a CSV file.