Structs
- Active
Ingredient - Active ingredient composition for a prescription
- Active
Ingridient Record - Admin
Route - Administration route for a prescription
- Administration
Route Record - AtcDuplicate
- ATC duplicate information
- AtcRecord
- Container
Record - Container
Unit Record - DcpRecord
- Dcpf
Record - Dcsa
Record - Excipient
Record - Header
- Laboratory
Record - Pharmaceutical
Form Record - Prescription
Atc - ATC code for a prescription
- Prescription
Form - Pharmaceutical form for a prescription
- Prescription
List - Prescription
Record - Registration
Status Record - Simplified
Pharmaceutical Form Record - Supply
Problem - Supply problem for a prescription
Functions
- parse_
atc_ xml_ to_ csv - Parses the ATC XML file and writes its content to a CSV file.
- parse_
dcp_ xml_ to_ csv - Parses the DCP XML file and writes its content to a CSV file.
- parse_
dcpf_ xml_ to_ csv - Parses the DCPF XML file and writes its content to a CSV file.
- parse_
dcsa_ xml_ to_ csv - Parses the DCSA XML file and writes its content to a CSV file.
- parse_
envases_ xml_ to_ csv - Parses the Envases XML file and writes its content to a CSV file.
- parse_
excipientes_ xml_ to_ csv - Parses the Excipientes XML file and writes its content to a CSV file.
- parse_
forma_ farmaceutica_ simplificada_ xml_ to_ csv - Parses the Forma Farmaceutica Simplificada XML file and writes its content to a CSV file.
- parse_
forma_ farmaceutica_ xml_ to_ csv - Parses the Forma Farmaceutica XML file and writes its content to a CSV file.
- parse_
laboratorio_ xml_ to_ csv - Parses the Laboratorio XML file and writes its content to a CSV file.
- parse_
prescription_ xml_ to_ csv - Parses the Prescription XML file and writes its content to a CSV file.
- parse_
prescription_ xml_ to_ csvs - Parses the Prescription XML file and writes content to multiple CSV files for normalized data.
- parse_
principio_ activo_ xml_ to_ csv - Parses the Principio Activo XML file and writes its content to a CSV file.
- parse_
situacion_ registro_ xml_ to_ csv - Parses the Situacion Registro XML file and writes its content to a CSV file.
- parse_
unidad_ contenido_ xml_ to_ csv - Parses the Unidad Contenido XML file and writes its content to a CSV file.
- parse_
via_ administracion_ xml_ to_ csv - Parses the Via Administracion XML file and writes its content to a CSV file.